=== modified file 'NEWS'
--- NEWS	2006-08-31 21:34:20 +0000
+++ NEWS	2006-09-05 21:35:51 +0000
@@ -31,6 +31,9 @@
       return urlescaped paths. This is now tested (there were bugs in a few
       of the transports) (Andrew Bennetts, David Allouche, John Arbash Meinel)
 
+    * New utility function symbol_versioning.deprecation_string. Returns the
+      formatted string for a callable, deprecation format pair. (Robert Collins)
+
 bzr 0.10.0RC1  2006-08-28
   
   IMPROVEMENTS:

=== modified file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	2006-08-28 17:04:38 +0000
+++ bzrlib/symbol_versioning.py	2006-09-05 21:35:51 +0000
@@ -57,6 +57,26 @@
 # add that on top of the primitives, once we have all three written
 # - RBC 20050105
 
+
+def deprecation_string(a_callable, deprecation_version):
+    """Generate an automatic deprecation string for a_callable.
+
+    :param a_callable: The callable to substitute into deprecation_version.
+    :param deprecation_version: A deprecation format warning string. This should
+        have a single %s operator in it. a_callable will be turned into a nice
+        python symbol and then substituted into deprecation_version.
+    """
+    if getattr(a_callable, 'im_class', None) is None:
+        symbol = "%s.%s" % (a_callable.__module__,
+                            a_callable.__name__)
+    else:
+        symbol = "%s.%s.%s" % (a_callable.im_class.__module__,
+                               a_callable.im_class.__name__,
+                               a_callable.__name__
+                               )
+    return deprecation_version % symbol
+
+
 def deprecated_function(deprecation_version):
     """Decorate a function so that use of it will trigger a warning."""
 
@@ -65,10 +85,8 @@
         
         def decorated_function(*args, **kwargs):
             """This is the decorated function."""
-            symbol = "%s.%s" % (callable.__module__, 
-                                callable.__name__
-                                )
-            warn(deprecation_version % symbol, DeprecationWarning, stacklevel=2)
+            warn(deprecation_string(callable, deprecation_version),
+                DeprecationWarning, stacklevel=2)
             return callable(*args, **kwargs)
         _populate_decorated(callable, deprecation_version, "function",
                             decorated_function)
@@ -87,7 +105,7 @@
         
         def decorated_method(self, *args, **kwargs):
             """This is the decorated method."""
-            symbol = "%s.%s.%s" % (self.__class__.__module__, 
+            symbol = "%s.%s.%s" % (self.__class__.__module__,
                                    self.__class__.__name__,
                                    callable.__name__
                                    )

=== modified file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	2006-07-12 16:20:00 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2006-09-05 21:35:51 +0000
@@ -142,3 +142,16 @@
         self.assertEqual(False,
                          symbol_versioning.deprecated_passed(
                             symbol_versioning.DEPRECATED_PARAMETER))
+
+    def test_deprecation_string(self):
+        """We can get a deprecation string for a method or function."""
+        self.assertEqual('bzrlib.tests.test_symbol_versioning.'
+            'TestDeprecationWarnings.test_deprecation_string was deprecated in '
+            'version 0.11.',
+            symbol_versioning.deprecation_string(
+            self.test_deprecation_string, symbol_versioning.zero_eleven))
+        self.assertEqual('bzrlib.symbol_versioning.deprecated_function was '
+            'deprecated in version 0.11.',
+            symbol_versioning.deprecation_string(
+                symbol_versioning.deprecated_function,
+                symbol_versioning.zero_eleven))

